complete -c mdcat -l columns -d 'Maximum number of columns to use for output. Defaults to 80 or the terminal width, whichever is smaller. Pass 0 to disable line wrapping' -r
complete -c mdcat -l completions -d 'Generate completions for a shell to standard output and exit' -r -f -a "bash\t''
elvish\t''
fish\t''
powershell\t''
zsh\t''"
complete -c mdcat -l theme -d 'Colour theme to use. Defaults to auto-detecting dark or light from the terminal' -r -f -a "auto\t'Detect dark/light mode from the terminal and pick accordingly'
dark\t'Use the built-in dark theme'
light\t'Use the built-in light theme'
catppuccin-mocha\t'Catppuccin Mocha (dark)'
catppuccin-latte\t'Catppuccin Latte (light)'
gruvbox-dark\t'Gruvbox dark'
gruvbox-light\t'Gruvbox light'
dracula\t'Dracula'
nord\t'Nord'
solarized-dark\t'Solarized dark'
solarized-light\t'Solarized light'"
complete -c mdcat -s c -l no-colour -d 'Disable all colours and other styles'
complete -c mdcat -s l -l local -d 'Do not load remote resources like images'
complete -c mdcat -l fail -d 'Exit immediately if any error occurs processing an input file'
complete -c mdcat -l detect-terminal -d 'Print detected terminal name and exit'
complete -c mdcat -l ansi -d 'Skip terminal detection and only use ANSI formatting'
complete -c mdcat -s p -l paginate -d 'Paginate the output of mdcat with a pager like less (default for mdless)'
complete -c mdcat -s P -l no-pager -d 'Do not paginate output (default). Overrides an earlier --paginate'
complete -c mdcat -s h -l help -d 'Print help (see more with \'--help\')'
complete -c mdcat -s V -l version -d 'Print version'
